use strict;
use warnings;
package MouseyDirty;

use Mouse;
use Scalar::Util 'refaddr';

sub stuff {}
1;
